package com.yihu.hos.datacollect.service;

import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.datacollect.model.RsJobConfig;
import com.yihu.hos.web.framework.model.Result;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import springfox.documentation.annotations.ApiIgnore;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 数据采集配置页面
 * Created by hzp on 2015/8/12.
 */
@RequestMapping("/datacollectEndpoint")
@ApiIgnore
@FeignClient(name = MicroServices.Standard)
public interface DataCollectClient {


    /*
    * 通过id获取job
     */
    @RequestMapping("getJobById")
    public RsJobConfig getJobById(String jobId);


    //获取方案列表
    @RequestMapping("getSchemeVersion")
    public List getSchemeVersion();


    /*
    获取任务列表
    */
    @RequestMapping("getJob")
    @ResponseBody
    public Result getJob(@RequestParam("name") final String name,
                         @RequestParam("page") final int page,
                         @RequestParam("rows") final int rows);

    @RequestMapping("compareServeTime")
    @ResponseBody
    public Result compareServeTime(@RequestParam("time") final String time);

    /**
     * 根据适配方案获取数据集列表
     */
    @RequestMapping("getSchemeDataset")
    @ResponseBody
    public Result getSchemeDataset(@RequestParam("schemeId") final String schemeId,
                                   @RequestParam("schemeVersion") final String schemeVersion,
                                   @RequestParam("jobId") final String jobId);

    /**
     * 根据适配方案+数据集获取字段列表
     */
    @RequestMapping("getSchemeDatasetCol")
    @ResponseBody
    public Result getSchemeDatasetCol
    (@RequestParam("schemeId") final String schemeId,
     @RequestParam("schemeVersion") final String schemeVersion,
     @RequestParam("datasetId") final String datasetId);

    /*
       新增任务
    */
    @RequestMapping("addJob")
    @ResponseBody
    public Result addJob(HttpServletRequest request);

    /*
       修改任务
    */
    @RequestMapping("updateJob")
    @ResponseBody
    public Result updateJob(HttpServletRequest request);

    /*
      修改任务状态
   */
    @RequestMapping("validJob")
    @ResponseBody
    public Result validJob(@RequestParam("jobId") final String jobId,
                           @RequestParam("valid") final String valid);

    /*
      删除任务
   */
    @RequestMapping("deleteJob")
    @ResponseBody
    public Result deleteJob(@RequestParam("jobId") final String jobId);

    /**
     * 获取任务信息
     *
     * @return
     */
    @RequestMapping("getJobInfo")
    @ResponseBody
    public Result getJobInfo(@RequestParam("jobId") final String jobId);

    /**
     * 根据任务Id获取相关数据集下拉数据
     *
     * @return
     */
    @RequestMapping("getJobDatasetByJobId")
    @ResponseBody
    public Result getJobDatasetByJobId(@RequestParam("jobId") final String jobId);

    /*************************
     * 数据集--数据源管理
     ******************************************/

    @RequestMapping("getDatasourceByOrg")
    public String getDatasourceByOrg(@RequestParam("orgCode") final String orgCode) throws Exception;

    /**
     * 数据集数据源管理列表（包含全部数据集）
     *
     * @return
     */
    @RequestMapping("getDatasetSource")
    @ResponseBody
    public Result getDatasetSource(@RequestParam("stdVersion") final String stdVersion);


    /**
     * 更新数据集数据源
     *
     * @return
     */
    @RequestMapping("saveDatasetSource")
    @ResponseBody
    public Result saveDatasetSource(@RequestParam("stdVersion") final String stdVersion,
                                    @RequestParam("json") final String json);


    /*************************** 任务执行 ************************************************/
    /**
     * 执行任务
     *
     * @return
     */
    @RequestMapping("executeJob")
    @ResponseBody
    public Result executeJob(@RequestParam("jobId") final String jobId);


    /*
    任务补采界面
     */
    @RequestMapping("repeatDatacollect")
    public String repeatDatacollect(Model model,
                                    @RequestParam("jobId") final String jobId,
                                    @RequestParam("jobDatasetId") final String jobDatasetId,
                                    @RequestParam("jobStatus") final String jobStatus,
                                    @RequestParam("jobTimeFrom") final String jobTimeFrom,
                                    @RequestParam("jobTimeTo") final String jobTimeTo);

    /**
     * 任务详细日志列表
     *
     * @return
     */
    @RequestMapping("getJobLogDetail")
    @ResponseBody
    public Result getJobLogDetail(@RequestParam("jobId") String jobId,
                                  @RequestParam("jobDatasetId") String jobDatasetId,
                                  @RequestParam("jobStatus") String jobStatus,
                                  @RequestParam("jobTimeFrom") String jobTimeFrom,
                                  @RequestParam("jobTimeTo") String jobTimeTo,
                                  @RequestParam("page") int page,
                                  @RequestParam("rows") int rows);


    /*************************** 任务跟踪 ***********************************/


    /**
     * 任务日志列表
     *
     * @return
     */
    @RequestMapping("getJobLog")
    @ResponseBody
    public Result getJobLog(@RequestParam("jobId") String jobId,
                            @RequestParam("rows") int page, int rows)
    ;

    /**
     * 任务详细根据数据集分组
     *
     * @return
     */
    @RequestMapping("getJobLogDataset")
    @ResponseBody
    public Result getJobLogDataset(@RequestParam("logId") String logId);
}
