package com.yihu.hos.resource.service;

import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.standard.model.adapter.AdapterDatasetModel;
import com.yihu.hos.standard.model.adapter.resultModel.AdapterMetadataResultDetailModel;
import com.yihu.hos.standard.model.adapter.resultModel.AdapterSchemeVersionResultDetailModel;
import com.yihu.hos.standard.model.standard.StdDataSetModel;
import com.yihu.hos.standard.model.standard.StdMetaDataModel;
import com.yihu.hos.web.framework.model.Result;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import springfox.documentation.annotations.ApiIgnore;

import java.util.List;
import java.util.Map;

/**
 * 数据采集配置页面
 * Created by hzp on 2015/8/12.
 */
@RequestMapping("/std1")
@ApiIgnore
@FeignClient(name = MicroServices.Standard)
public interface StdClient {



    @RequestMapping("getDictByScheme")
    @ResponseBody
    public Result getDictByScheme(@RequestParam(value = "version") String version,
                                  @RequestParam(value = "dictId") String dictId);



    /**************************** 适配方案 **************************************************/

    /**
     * 获取适配方案列表
     * @return
     */
    @RequestMapping("getSchemeVersion")
    @ResponseBody
    public List<AdapterSchemeVersionResultDetailModel> getSchemeVersion();

    /**
     * 通过适配方案获取数据集列表
     * @return
     */
    @RequestMapping("getDatasetByScheme")
    @ResponseBody
    public List<AdapterDatasetModel> getDatasetByScheme( @RequestParam(value = "schemeVersion") String schemeVersion);

    /**
     * 通过适配方案获取字段列表
     * @return
     */
    @RequestMapping("getMetadatasByScheme")
    @ResponseBody
    public List<AdapterMetadataResultDetailModel> getMetadatasByScheme(
            @RequestParam(value = "schemeVersion") String schemeVersion,
            @RequestParam(value = "datasetId") String datasetId) ;


    /******************************** 标准版本 *****************************************************/

    /**
     * 通过标准版本获取数据集列表
     * @return
     */
    @RequestMapping("getDatasetByVersion")
    @ResponseBody
    public List<StdDataSetModel> getDatasetByVersion( @RequestParam(value = "stdVersion") String stdVersion) ;

    /**
     * 根据数据集code得到数据元
     * @return
     */
    @RequestMapping("metadatasAllVersionList")
    @ResponseBody
    public List<StdMetaDataModel> metadatasAllVersionList( @RequestParam(value = "params") Map<String, Object> params) ;

    /**
     * 得到全部版本的数据元
     * @return
     */
    @RequestMapping("datasetsAllVersionList")
    @ResponseBody
    public List<StdDataSetModel> datasetsAllVersionList();


    @RequestMapping("datasetVersionListByName")
    @ResponseBody
    public List datasetVersionListByName(@RequestParam(value = "rsResourceImportDatasetDialogName") String rsResourceImportDatasetDialogName) ;


}
