package com.yihu.hos.standard.service.adapter;

import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.standard.model.adapter.AdapterDatasetModel;
import com.yihu.hos.web.framework.model.DetailModelResult;
import com.yihu.hos.web.framework.model.Result;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import springfox.documentation.annotations.ApiIgnore;

/**
 * Created by LLH on 2016/1/6.
 */

@RequestMapping("/adapterDatasetEndpoint")
@ApiIgnore
@FeignClient(name = MicroServices.Standard)
public interface AdapterDatasetClient  {


    @RequestMapping(value = "/searchDatasetList")
    @ApiOperation(value = "获取数据集列表", response = DetailModelResult.class, produces = "application/json", notes = "获取数据集列表")
    public DetailModelResult getDatasetList(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "order", required = false) String order,
            @RequestParam(value = "rows", required = false) Integer rows,
            @RequestParam(value = "page", required = false) Integer page);

    @RequestMapping("/getForDatasetId")
    @ApiOperation(value = "获取适配数据集", response = Result.class, produces = "application/json", notes = "获取适配数据集")
    public AdapterDatasetModel getForDatasetId(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "datasetId") Integer datasetId) ;

    @RequestMapping(value = "/delDataset")
    @ApiOperation(value = "删除数据集", response = Result.class, produces = "application/json", notes = "删除适配数据集")
    public Result delDataset(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "datasetId") Integer datasetId) ;

    @RequestMapping(value = "/updateDataset")
    @ApiOperation(value = "修改适配数据集", response = Result.class, produces = "application/json", notes = "修改适配数据集")
    public AdapterDatasetModel modify(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "dataset") String dataset);

    @RequestMapping(value = "/addDataset")
    @ApiOperation(value = "保存适配数据集", response = Result.class, produces = "application/json", notes = "保存数据集")
    public AdapterDatasetModel add(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "dataset") String dataset) ;

    @RequestMapping(value = "/getAdapterDataset")
    @ApiOperation(value = "获取定制数据集列表", response = DetailModelResult.class, responseContainer = "List",produces = "application/json", notes = "获取数据集列表")
    public DetailModelResult getDatasetCustomize(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "stdVersion") String stdVersion) ;

    @RequestMapping(value = "/saveAdapterDataset", method = RequestMethod.POST)
    @ApiOperation(value = "定制适配数据集", response = Result.class, responseContainer = "List",produces = "application/json", notes = "获取数据集列表")
    public Result adapterDataSet(
            @RequestParam(value = "schemeId") Integer schemeId,
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "stdVersion") String stdVersion,
            @RequestParam(value = "datasetIdStr") String datasetIdStr,
            @RequestParam(value = "metaDataIdStr") String metaDataIdStr) ;
}
