package com.yihu.hos.standard.service.adapter;

import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.standard.model.adapter.AdapterMetadataModel;
import com.yihu.hos.web.framework.model.ActionResult;
import com.yihu.hos.web.framework.model.DetailModelResult;
import com.yihu.hos.web.framework.model.Result;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import springfox.documentation.annotations.ApiIgnore;

/**
 * Created by LLH on 2016/1/6.
 */

@RequestMapping("/adapterMetadataEndpoint")
@ApiIgnore
@FeignClient(name = MicroServices.Standard)
public interface AdapterMetadataClient {

    @RequestMapping("/searchMetadataList")
    public DetailModelResult getMetadataList(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "order", required = false) String order,
            @RequestParam(value = "rows", required = false) Integer rows,
            @RequestParam(value = "page", required = false) Integer page) ;

    @RequestMapping("/getForMetadataId")
     public AdapterMetadataModel get(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "metadataId") Integer metadataId) ;

    @RequestMapping("/updateMetadata")
    public AdapterMetadataModel updateMetadata(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "metadata") String metadata);

    @RequestMapping("/addMetadata")
    public AdapterMetadataModel addMetadata(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "metadata") String metadata) ;

    @RequestMapping("/updateMetadatas")
    public DetailModelResult updateMetadatas(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "list") String list);

    @RequestMapping("/delMetadata")
    public Result delete(
            @RequestParam(value = "adapterVersion") String adapterVersion,
            @RequestParam(value = "metadataId") Integer metadataId,
            @RequestParam(value = "stdDatasetId") Integer stdDatasetId,
            @RequestParam(value = "adapterDatasetId") Integer adapterDatasetId) ;

    @RequestMapping(value = "/isStrategy", method = RequestMethod.POST , produces = "application/json")
    @ResponseBody
    public ActionResult isStrategy(
            @ApiParam(value = "匹配version", required = true) @RequestParam("version") String version
    );

    /**
     * 智能匹配
     *
     * @param version
     * @return
     * @throws Exception
     */
    @ResponseBody
    @RequestMapping(value = "/strategy", method = RequestMethod.POST)
    @ApiOperation(value = "智能匹配", response = Object.class, produces = "application/json", notes = "智能匹配")
    public ActionResult strategy(
            @ApiParam(value = "匹配version", required = true) @RequestParam("version") String version,
            @ApiParam(value = "平台标准version", required = true) @RequestParam("std_version") String std_version,
            @ApiParam(value = "适配方案版本号", required = true) @RequestParam("adapter_std_version") String adapter_std_version
    ) ;

    @RequestMapping(value = "/getStrategySize", method = RequestMethod.POST)
    @ResponseBody
    public ActionResult getStrategySize(
            @ApiParam(value = "匹配version", required = true) @RequestParam("version") String version
    ) ;

    @RequestMapping(value = "/endStrategy", method = RequestMethod.POST)
    @ResponseBody
    public ActionResult endStrategy(
            @ApiParam(value = "匹配version", required = true) @RequestParam("version") String version
    ) ;
}

