package com.yihu.hos.standard.service.standard;

import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.standard.model.adapter.AdapterSchemeModel;
import com.yihu.hos.web.framework.model.DetailModelResult;
import com.yihu.hos.web.framework.model.Result;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import springfox.documentation.annotations.ApiIgnore;

@RequestMapping("/schemeEndpoint")
@ApiIgnore
@FeignClient(name = MicroServices.Standard)
public interface SchemeClient  {

    @RequestMapping(value = "/searchScheme")
    @ApiOperation(value = "获取方案列表", response = DetailModelResult.class, responseContainer = "List", notes = "获取方案列表")
    public DetailModelResult searchScheme(
            @ApiParam(name = "condition", value = "查询条件：适配方案名称、适配方案版本名称")
            @RequestParam(value = "condition", required = false) String condition) ;

    /**
     * 根据适配ID获取适配方案信息（get）
     * @param schemeId
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getForSchemeId")
    @ApiOperation(value = "获取适配方案", response = Result.class, produces = "application/json", notes = "获取适配方案")
    public AdapterSchemeModel get(
            @ApiParam(name = "schemeId", value = "标准版本ID")
            @RequestParam(value = "schemeId") Integer schemeId) ;

    /**
     * 修改适配（PUT）
     * @param scheme
     * @return
     * @throws Exception
     */
    @RequestMapping("/updateScheme")
    @ApiOperation(value = "修改适配方案", response = Result.class, produces = "application/json", notes = "修改适配方案")
    public AdapterSchemeModel modify(
            @ApiParam(name = "scheme", value = "适配方案")
            @RequestParam(value = "scheme") String scheme) ;

    /**
     * 新增适配（POST）
     * @param scheme
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/addScheme")
    @ApiOperation(value = "保存适配方案", response = Result.class, produces = "application/json", notes = "保存适配方案")
    public AdapterSchemeModel add(
            @ApiParam(name = "scheme", value = "适配方案信息")
            @RequestParam(value = "scheme") String scheme);

    /**
     * 删除适配（DELETE）
     * @param  schemeId
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/deleteScheme")
    @ApiOperation(value = "删除适配方案", response = Result.class, produces = "application/json", notes = "删除适配方案")
    public Result delete(
            @ApiParam(name = "schemeId", value = "适配方案ID")
            @RequestParam(value = "schemeId") Integer schemeId) ;
}
