package com.yihu.hos.standard.service.standard;

import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.standard.model.adapter.AdapterSchemeVersionModel;
import com.yihu.hos.web.framework.model.DataGridResult;
import com.yihu.hos.web.framework.model.DictionaryResult;
import com.yihu.hos.web.framework.model.Result;
import com.yihu.hos.web.framework.model.TreeResult;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import springfox.documentation.annotations.ApiIgnore;

import java.util.List;
@RequestMapping("/schemeVersionEndpoint")
@ApiIgnore
@FeignClient(name = MicroServices.Standard)
public interface SchemeVersionClient  {


    @RequestMapping("/getForVersionId")
    @ApiOperation(value = "获取适配版本", response = Result.class, produces = "application/json", notes = "获取适配版本")
    public AdapterSchemeVersionModel get(
            @RequestParam(value = "versionId") Integer versionId);

    /**
     * 新增版本（post）
     * @param version
     * @return
     * @throws Exception
     */
    @RequestMapping("/addVersion")
    @ApiOperation(value = "保存适配版本", response = Result.class, produces = "application/json", notes = "保存适配版本")
    public AdapterSchemeVersionModel add(
            @RequestParam(value = "version") String version) ;

    /**
     * 修改版本（put）
     * @param version
     * @return
     * @throws Exception
     */
    @RequestMapping("/updateVersion")
    @ApiOperation(value = "修改适配版本", response = Result.class, produces = "application/json", notes = "修改适配版本")
    public AdapterSchemeVersionModel modify(
            @RequestParam(value = "version") String version);

    /**
     * 发布版本（put）
     * @param versionId
     * @return
     * @throws Exception
     */
    @RequestMapping("/publishVersion")
    @ApiOperation(value = "发布适配版本", response = Result.class, produces = "application/json", notes = "发布适配版本")
    public AdapterSchemeVersionModel publish(
            @RequestParam(value = "versionId") Integer versionId,
            @RequestParam(value = "publisher", required = false) String publisher);

    /**
     * 删除版本（put）
     * @param versionId
     * @return
     * @throws Exception
     */
    @RequestMapping("/deleteVersion")
    @ApiOperation(value = "删除版本", response = Result.class, produces = "application/json", notes = "删除版本")
    public Result delete(
            @RequestParam(value = "versionId") Integer versionId) ;

    @RequestMapping("getVersion")
    @ResponseBody
    public DataGridResult getVersion() ;

    @RequestMapping("getVersionTree")
    @ResponseBody
    public List<TreeResult> getVersionTree() ;

    /**
     * 获取基础版本列表
     * @param schemeId
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getVersions")
    @ApiOperation(value = "获取适配方案版本列表", response = DictionaryResult.class, produces = "application/json", notes = "获取标准版本列表")
    public DictionaryResult getList(
            @RequestParam(value = "schemeId") Integer schemeId,
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "order", required = false) String order,
            @RequestParam(value = "rows", required = false) Integer rows,
            @RequestParam(value = "page", required = false) Integer page);
}
