package com.yihu.hos.standard.service.standard;

import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.standard.model.standard.StandardModel;
import com.yihu.hos.standard.model.standard.resultModel.StandardParamResultModel;
import com.yihu.hos.web.framework.model.DetailModelResult;
import com.yihu.hos.web.framework.model.DictionaryResult;
import com.yihu.hos.web.framework.model.Result;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import springfox.documentation.annotations.ApiIgnore;

/**
 * @created Airhead 2015/12/23.
 */

@RequestMapping("/standardEndpoint")
@ApiIgnore
@FeignClient(name = MicroServices.Standard)
public interface StandardClient {

    @RequestMapping("/searchStandard")
    public DetailModelResult searchStandard(
            @RequestParam(value = "condition", required = false) String condition) ;

    /**
     * 获取集成标准系统参数
     * @return
     * @throws Exception
     */
    @RequestMapping("/getSysParamList")
    public StandardParamResultModel getSysParamList() ;


    /**
     * 根据标准ID获取集成标准信息（get）
     * @param standardId
     * @return
     * @throws Exception
     */
    @RequestMapping("/getForStandardId")
    public StandardModel getForStandardId(
            @RequestParam(value = "standardId") Integer standardId);

    /**
     * 修改标准信息（PUT）
     * @param standard
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/updateStandard", method = RequestMethod.POST)
    public StandardModel modify(
            @RequestParam(value = "standard") String standard);

    /**
     * 新增标准信息（POST）
     * @param standard
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/addStandard", method = RequestMethod.POST)
    public StandardModel add(
            @RequestParam(value = "standard") String standard);

    /**
     * 删除标准信息（DELETE）
     * @param  standardId
     * @return
     * @throws Exception
     */
    @RequestMapping("/deleteStandard")
    public Result delete(
            @RequestParam(value = "standardId") Integer standardId);

    /**
     * 获取平台标准名称/应用标准名称列表
     * @param condition
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/getStandards")
    public DictionaryResult getStandardList(
            @RequestParam(value = "condition", required = false) String condition,
            @RequestParam(value = "order", required = false) String order,
            @RequestParam(value = "rows", required = false) Integer rows,
            @RequestParam(value = "page", required = false) Integer page);


}
