package com.yihu.hos.standard.service.standard;

import com.yihu.hos.core.constants.MicroServices;
import com.yihu.hos.standard.model.standard.StandardVersionModel;
import com.yihu.hos.web.framework.model.ActionResult;
import com.yihu.hos.web.framework.model.DictionaryResult;
import com.yihu.hos.web.framework.model.Result;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.multipart.MultipartFile;
import springfox.documentation.annotations.ApiIgnore;

/**
 * Created by LLH on 2016/1/6.
 */

@RequestMapping("/standardVersionEndpoint")
@ApiIgnore
@FeignClient(name = MicroServices.Standard)
public interface StandardVersionClient {

    /**
     * 根据版本id获取标准版本信息（get）
     * @param versionId
     * @return
     * @throws Exception
     */
    @RequestMapping("/getForVersionId")
    public StandardVersionModel getForVersionId(
            @RequestParam(value = "versionId") Integer versionId) ;

    /**
     * 新增版本（post）
     * @param version
     * @return
     * @throws Exception
     */
    @RequestMapping("/addVersion")
    public StandardVersionModel addVersion(
            @RequestParam(value = "version") String version) ;

    /**
     * 修改版本（put）
     * @param version
     * @return
     * @throws Exception
     */
    @RequestMapping("/updateVersion")
    public StandardVersionModel updateVersion(
            @RequestParam(value = "version") String version) ;

    /**
     * 发布版本（post）
     * @param versionId
     * @param publisher
     * @return
     * @throws Exception
     */
    @RequestMapping("/publishVersion")
    public StandardVersionModel publish(
            @RequestParam(value = "versionId") Integer versionId,
            @RequestParam(value = "publisher") String publisher) ;

    /**
     * 删除版本（put）
     * @param versionId
     * @return
     * @throws Exception
     */
    @RequestMapping("/deleteVersion")
    public Result delete(
            @RequestParam(value = "versionId") Integer versionId,
            @RequestParam(value = "version") String version);

    /**
     * 获取基础版本名称列表
     * @param standardId
     * @return
     * @throws Exception
     */
    @RequestMapping("/getVersions")
    public DictionaryResult getVersions(
            @RequestParam(value = "standardId") Integer standardId,
            @RequestParam(value = "condition") String condition,
            @RequestParam(value = "order") String order,
            @RequestParam(value = "rows") Integer rows,
            @RequestParam(value = "page") Integer page) ;
    /**
     * 根据类型文件上传保存对应的数据
     *
     * @param type
     * @param file
     * @return
     * @throws Exception
     */
   
    @RequestMapping(value = "/importFile", method = RequestMethod.POST)
    public ActionResult importFile(@RequestParam("type") String type,
                                   @RequestParam(value = "version") String version,
                                   @RequestParam(value = "standardId") Integer standardId,
                                   @RequestParam(value = "file") MultipartFile file);

   
    @RequestMapping(value = "/isUpdateDatasetAndDict", method = RequestMethod.POST)
    public ActionResult isUpdateDatasetAndDict(
            @RequestParam(value = "version") String version) ;

    /**
     * 根据类型和主键删除数据
     *
     * @param type
     * @return
     * @throws Exception
     */
   
    @RequestMapping(value = "/deleteByType", method = RequestMethod.POST)
    public ActionResult deleteByType(
            @RequestParam(value = "type") String type,
             @RequestParam(value = "version") String version) ;

}

