package com.yihu.hos.system.controller;

import com.yihu.ehr.constants.ApiVersion;
import com.yihu.hos.config.BeanConfig;
import com.yihu.hos.fegin.AppFeatureFegin;
import com.yihu.hos.system.model.AppFeature;
import com.yihu.hos.web.framework.constant.ContextAttributes;
import com.yihu.hos.web.framework.model.Envelop;
import com.yihu.hos.web.framework.thread.LocalContext;
import com.yihu.hos.web.framework.util.controller.BaseController;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import net.sf.json.JSONObject;
import org.apache.commons.beanutils.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.client.RestTemplate;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * 应用管理
 */
@RequestMapping("/app/feature")
@Controller
public class AppFeatureController extends BaseController {
    @Autowired
    private BeanConfig beanConfig;
    @Autowired
    private RestTemplate restTemplate;

    @Autowired
    private AppFeatureFegin appFeatureFegin;

    @Value("${service-gateway.appService}"+ ApiVersion.Version1_0+"/appFeature")
    private String appService;

    /**
     *  应用功能管理界面
     *
     * @param model
     * @return
     */
    @RequestMapping("/initial")
    public String gotoList(Model model, String dataModel){
        model.addAttribute("dataModel",dataModel);
        model.addAttribute("contentPage", "system/app/feature/appFeature");
        return "partView";
    }

    @RequestMapping(value="/list",produces = "application/json;charset=UTF-8")
    @ResponseBody
    public Object search(String parentId, String appId){
        try{
            Map<String, Object> params = new HashMap<>();
            Map<String, Object> filtersMap = new HashMap<>();
            filtersMap.put("parentId",parentId);
            filtersMap.put("appId",appId);
            String filters = JSONObject.fromObject(filtersMap).toString();
            params.put("filters",filters);
            String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
            Envelop envelop = appFeatureFegin.getAppFeatureNoPage(filters, null, schemaName);
            return toJson(envelop);
        } catch (Exception e) {
            e.printStackTrace();
            Envelop result = new Envelop();
            result.setSuccessFlg(false);
            result.setErrorMsg("系统错误");
            return toJson(result);
        }
    }


    @RequestMapping(value="/tree",produces = "application/json; charset=utf-8")
    @ResponseBody
    public Object tree(String appId, String appName) {
        Map<String, Object> params = new HashMap<>();
        String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
        params.put("schemaName",schemaName);
        params.put("appId",appId);
        params.put("appName",appName);
        ResponseEntity<String> responseEntity = restTemplate.getForEntity(appService+"/tree?appId={appId}&appName={appName}&schemaName={schemaName}", String.class,params);
        return responseEntity.getBody();
    }

    @RequestMapping("/gotoModify")
    public Object gotoModify(Model model, Integer id, String mode, String extParms,String appId,Integer parentId){
        try {
            Envelop envelop = new Envelop();

            Map<String, Object> params = new HashMap<>();
            params.put("id",id);
            params.put("mode",mode);
            params = putAll(extParms, params);

            if (!StringUtils.isEmpty(id)){ //如果id不为空,则通过微服务查询
                String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
                envelop = appFeatureFegin.getById(id,schemaName);
            }

            Object appFeature;
            if(envelop.getObj()==null){
                AppFeature tem = new AppFeature();
                tem.setAppId(appId);
                tem.setParentId(parentId);
                appFeature = tem;
            } else {
                appFeature =envelop.getObj();
            }

            model.addAttribute("model",appFeature);
            model.addAttribute("mode",mode);
            if("add".equals(mode)){
                model.addAttribute("contentPage", "/system/app/feature/dialog");
                model.addAttribute("flag", "");
            }else {
                model.addAttribute("contentPage", "/system/app/feature/dialog");
                model.addAttribute("flag", "disabled");
            }
            model.addAttribute("staged", params.get("staged"));
            return "pageView";
        } catch (Exception e) {
            e.printStackTrace();
            Envelop result = new Envelop();
            result.setSuccessFlg(false);
            result.setErrorMsg("系统错误");
            return result;
        }
    }


    /**
     * 新增应用功能
     * @param request
     * @return
     */
    @RequestMapping("/add")
    @ResponseBody
    public Envelop add(HttpServletRequest request) {
        Envelop envelop = new Envelop();
        try {
            AppFeature obj = new AppFeature();
            BeanUtils.populate(obj, request.getParameterMap());
            obj.setId(null);

            Map<String, Object> params = new HashMap<>();
            String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
            params.put("schemaName",schemaName);

            JSONObject jsonObj = JSONObject.fromObject(obj);
            AppFeature feature = appFeatureFegin.create(jsonObj.toString(),schemaName);
            if(feature!=null){
                envelop.setSuccessFlg(true);
                envelop.setObj(feature);
                return envelop;
            }else{
                envelop.setSuccessFlg(false);
                envelop.setObj(feature);
                envelop.setErrorMsg("保存失败");
                return envelop;
            }
        } catch (Exception ex) {
            ex.printStackTrace();
            envelop.setSuccessFlg(false);
            envelop.setErrorMsg(ex.getMessage());
            return envelop;
        }
    }

    @RequestMapping("/existence")
    @ResponseBody
    public Object isExistence(String filters){
        try {
            String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
            Envelop envelop = appFeatureFegin.isExist(filters, schemaName);
            return toJson(envelop);
        } catch (Exception e) {
            e.printStackTrace();
            Envelop result = new Envelop();
            result.setSuccessFlg(false);
            result.setErrorMsg("系统错误");
            return toJson(result);
        }
    }

    @RequestMapping(value = "/delete", method = RequestMethod.DELETE)
    @ApiOperation(value = "删除AppFeature")
    @ResponseBody
    public Envelop deleteAppFeature(
            @ApiParam(name = "id", value = "id", defaultValue = "")
            @RequestParam(value = "id") Integer id) {
        String schemaName = LocalContext.getContext().getAttachment(ContextAttributes.SCHEMA);
        Envelop envelop = appFeatureFegin.delete(id,schemaName);
        return envelop;
    }

    private String nullToSpace(String str){
        if(str == null)
            return "";
        return str;
    }




    //public Map beforeGotoModify(Map params){
    //
    //    return params;
    //}
    //
    //public Object afterGotoModify(Object rs, Map params){
    //
    //    return rs;
    //}


}
